@@ -1739,3 +1739,54 @@ INSERT INTO `VSEnabledPorts` VALUES (928,1,'TCP',80,1,NULL,NULL);
 INSERT INTO `VSEnabledPorts` VALUES (928,1,'TCP',443,1,NULL,NULL);
 INSERT INTO `VSEnabledPorts` VALUES (929,1,'TCP',80,1,NULL,NULL);
 INSERT INTO `VSEnabledPorts` VALUES (929,1,'TCP',443,1,NULL,NULL);
+
+INSERT INTO `PatchCableHeap` (id, pctype_id, end1_conn_id, end2_conn_id, amount, length, description) VALUES
+(1,2,9,9,97,2.00,''),
+(2,2,9,3,98,2.00,''),
+(3,13,13,13,100,1.00,'blue'),
+(4,13,13,13,100,1.00,'green'),
+(5,13,13,13,98,1.00,'yellow'),
+(6,13,13,13,49,2.00,'gray'),
+(7,27,15,15,10,0.50,'direct attach'),
+(8,25,15,15,20,2.00,'direct attach'),
+(9,24,15,15,15,7.00,'direct attach'),
+(10,20,999,999,5,2.00,''),
+(11,18,5,5,9,5.00,'fiber ribbon'),
+(12,22,7,7,11,10.00,'fiber ribbon'),
+(13,11,1,11,5,0.50,'converter'),
+(14,11,1,9,4,1.00,'converter');
+
+INSERT INTO `PatchCableHeapLog` (id, heap_id, date, user, message) VALUES
+(1,14,'2014-06-15 00:10:24','admin','amount set to 5'),
+(2,13,'2014-06-15 00:10:28','admin','amount set to 5'),
+(3,2,'2014-06-15 00:10:34','admin','amount set to 100'),
+(4,1,'2014-06-15 00:10:42','admin','amount set to 100'),
+(5,3,'2014-06-15 00:10:49','admin','amount set to 100'),
+(6,6,'2014-06-15 00:10:56','admin','amount set to 50'),
+(7,4,'2014-06-15 00:10:59','admin','amount set to 100'),
+(8,5,'2014-06-15 00:11:01','admin','amount set to 100'),
+(9,12,'2014-06-15 00:11:07','admin','amount set to 10'),
+(10,11,'2014-06-15 00:11:09','admin','amount set to 10'),
+(11,10,'2014-06-15 00:11:12','admin','amount set to 5'),
+(12,7,'2014-06-15 00:11:16','admin','amount set to 2'),
+(13,8,'2014-06-15 00:11:28','admin','amount set to 20'),
+(14,9,'2014-06-15 00:11:34','admin','amount set to 15'),
+(15,7,'2014-06-15 00:14:22','admin','amount adjusted by 1'),
+(16,7,'2014-06-15 00:14:24','admin','amount adjusted by 1'),
+(17,7,'2014-06-15 00:14:25','admin','amount adjusted by 1'),
+(18,7,'2014-06-15 00:14:26','admin','amount adjusted by 1'),
+(19,7,'2014-06-15 00:14:27','admin','amount adjusted by 1'),
+(20,7,'2014-06-15 00:14:29','admin','amount adjusted by 1'),
+(21,7,'2014-06-15 00:14:30','admin','amount adjusted by 1'),
+(22,7,'2014-06-15 00:14:31','admin','amount adjusted by 1'),
+(23,6,'2014-06-15 00:14:35','admin','amount adjusted by -1'),
+(24,12,'2014-06-15 00:14:38','admin','amount adjusted by 1'),
+(25,11,'2014-06-15 00:14:40','admin','amount adjusted by -1'),
+(26,1,'2014-06-15 00:14:42','admin','amount adjusted by -1'),
+(27,1,'2014-06-15 00:14:44','admin','amount adjusted by -1'),
+(28,1,'2014-06-15 00:14:45','admin','amount adjusted by -1'),
+(29,2,'2014-06-15 00:14:47','admin','amount adjusted by -1'),
+(30,2,'2014-06-15 00:14:50','admin','amount adjusted by -1'),
+(31,5,'2014-06-15 00:14:51','admin','amount adjusted by -1'),
+(32,5,'2014-06-15 00:14:52','admin','amount adjusted by -1'),
+(33,14,'2014-06-15 00:14:57','admin','amount adjusted by -1');
