@@ -327,7 +327,7 @@ function printNiftySelect ($groupList, $select_attrs = array(), $selected_id = N
 // Input is a cooked list of OPTGROUPs, each with own sub-list of OPTIONs in the same
 // format as printSelect() expects.
 // If tree is true, hierarchical drop-boxes are used, otherwise optgroups are used.
-function getNiftySelect ($groupList, $select_attrs, $selected_id = NULL, $tree = false)
+function getNiftySelect ($groupList, $select_attrs, $selected_id = NULL)
 {
 	// special treatment for ungrouped data
 	if (count ($groupList) == 1 and isset ($groupList['other']))
@@ -336,96 +336,49 @@ function getNiftySelect ($groupList, $select_attrs, $selected_id = NULL, $tree =
 		return '';
 	if (!array_key_exists ('id', $select_attrs))
 		$select_attrs['id'] = $select_attrs['name'];
-	if ($tree)
+
+	$ret = '<select';
+	foreach ($select_attrs as $attr_name => $attr_value)
+		$ret .= " ${attr_name}=${attr_value}";
+	$ret .= ">\n";
+	foreach ($groupList as $groupname => $groupdata)
 	{
-		# it is safe to call many times for the same file
-		addJS ('js/jquery.optionTree.js');
-		$ret  = "<input type=hidden name=${select_attrs['name']}>\n";
-		$ret .= "<script type='text/javascript'>\n";
-		$ret .= "\$(function() {\n";
-		$ret .= "    var option_tree = {\n";
-		foreach ($groupList as $groupname => $groupdata)
-		{
-			$ret .= "        '${groupname}': {";
-			foreach ($groupdata as $dict_key => $dict_value)
-				$ret .= "\"${dict_value}\":'${dict_key}', ";
-			$ret .= "},\n";
-		}
-		$ret .= "    };\n";
-		$ret .= "    var options = {empty_value: '', choose: 'select...'};\n";
-		$ret .= "    \$('input[name=${select_attrs['name']}]').optionTree(option_tree, options);\n";
-		$ret .= "});\n";
-		$ret .= "</script>\n";
-	}
-	else
-	{
-		$ret = '<select';
-		foreach ($select_attrs as $attr_name => $attr_value)
-			$ret .= " ${attr_name}=${attr_value}";
-		$ret .= ">\n";
-		foreach ($groupList as $groupname => $groupdata)
-		{
-			$ret .= "<optgroup label='${groupname}'>\n";
-			foreach ($groupdata as $dict_key => $dict_value)
-				$ret .= "<option value='${dict_key}'" . ($dict_key == $selected_id ? ' selected' : '') . ">${dict_value}</option>\n";
-			$ret .= "</optgroup>\n";
-		}
-		$ret .= "</select>\n";
+		$ret .= "<optgroup label='${groupname}'>\n";
+		foreach ($groupdata as $dict_key => $dict_value)
+			$ret .= "<option value='${dict_key}'" . ($dict_key == $selected_id ? ' selected' : '') . ">${dict_value}</option>\n";
+		$ret .= "</optgroup>\n";
 	}
+	$ret .= "</select>\n";
 	return $ret;
 }
 
 function getOptionTree ($tree_name, $tree_options, $tree_config = array())
 {
-	function serializeJSArray ($options)
-	{
-		$tmp = array();
-		foreach ($options as $key => $value)
-			$tmp[] = "'${key}': \"${value}\"";
-		return '{' . implode (', ', $tmp) . "}\n";
-	}
-	function serializeJSTree ($tree_options)
-	{
-		$self = __FUNCTION__;
-		$tmp = array();
-		# Leaves on the PHP tree are stored "value => label" way,
-		# non-leaves are stored "label => array" way, and the JS
-		# tree is always built "label => value" or "label => array"
-		# way, hence a structure transform is required.
-		foreach ($tree_options as $key => $value)
-			$tmp[] = is_array ($value) ?
-				'"' . str_replace ('"', '\"', $key) . '": ' . $self ($value) :
-				'"' . str_replace ('"', '\"', $value) . '": "' . str_replace ('"', '\"', $key) . '"';
-		return '{' . implode (', ', $tmp) . "}\n";
-	}
-
 	$default_config = array
 	(
 		'choose' => 'select...',
 		'empty_value' => '',
+		'indexed' => true,
 	);
-	foreach ($tree_config as $cfgoption_name => $cfgoption_value)
-		$default_config[$cfgoption_name] = $cfgoption_value;
-	# it is safe to call many times for the same file
 	addJS ('js/jquery.optionTree.js');
-	$ret  = "<input type=hidden name=${tree_name}>\n";
-	$ret .= "<script type='text/javascript'>\n";
-	$ret .= "\$(function() {\n";
-	$ret .= "    var option_tree = " . serializeJSTree ($tree_options) . ";\n";
-	$ret .= "    var options = " . serializeJSArray ($default_config) . ";\n";
-	$ret .= "    \$('input[name=${tree_name}]').optionTree(option_tree, options);\n";
-	$ret .= "});\n";
-	$ret .= "</script>\n";
-	return $ret;
+	addJS ("
+$(function() {
+	var option_tree = " . json_encode ($tree_options) . ";
+	var options = " . json_encode ($tree_config + $default_config) . ";
+	$('input[name=${tree_name}]').optionTree(option_tree, options);
+});
+", TRUE);
+
+	return "<input type=hidden name=${tree_name}>";
 }
 
-function printImageHREF ($tag, $title = '', $do_input = FALSE, $tabindex = 0)
+function printImageHREF ($tag, $title = '', $do_input = FALSE)
 {
-	echo getImageHREF ($tag, $title, $do_input, $tabindex);
+	echo getImageHREF ($tag, $title, $do_input);
 }
 
 // this would be better called mkIMG(), make "IMG" HTML element
-function getImageHREF ($tag, $title = '', $do_input = FALSE, $tabindex = 0)
+function getImageHREF ($tag, $title = '', $do_input = FALSE)
 {
 	global $image;
 	if (!isset ($image[$tag]))
@@ -437,7 +390,6 @@ function getImageHREF ($tag, $title = '', $do_input = FALSE, $tabindex = 0)
 			"<input type=image name=submit class=icon " .
 			"src='${img['path']}' " .
 			"border=0 " .
-			($tabindex ? "tabindex=${tabindex}" : '') .
 			(!strlen ($title) ? '' : " title='${title}'") . // JT: Add title to input hrefs too
 			">";
 	else
@@ -507,7 +459,7 @@ function transformRequestData()
 function addJS ($data, $inline = FALSE, $group = 'default')
 {
 	static $javascript = array();
-	static $seen_filenames = array();
+	static $seen_data = array();
 
 	if (! isset ($data))
 	{
@@ -530,23 +482,17 @@ function addJS ($data, $inline = FALSE, $group = 'default')
 		foreach ($javascript as $group_name => $group_array)
 			foreach ($group_array as $item)
 				if ($item['type'] == 'file')
-					$seen_filenames[$item['script']] = 1;
+					$seen_data[$item['script']] = 1;
 	}
 
-	if ($inline)
-		$javascript[$group][] = array
-		(
-			'type' => 'inline',
-			'script' => $data,
-		);
-	elseif (! isset ($seen_filenames[$data]))
+	if (! isset ($seen_data[$data]))
 	{
 		$javascript[$group][] = array
 		(
-			'type' => 'file',
+			'type' => $inline ? 'inline' : 'file',
 			'script' => $data,
 		);
-		$seen_filenames[$data] = 1;
+		$seen_data[$data] = 1;
 	}
 }
 
@@ -557,24 +503,18 @@ function addJS ($data, $inline = FALSE, $group = 'default')
 function addCSS ($data, $inline = FALSE)
 {
 	static $styles = array();
-	static $seen_filenames = array();
+	static $seen_data = array();
 
 	if (! isset ($data))
 		return $styles;
-	if ($inline)
-		$styles[] = array
-		(
-			'type' => 'inline',
-			'style' => $data,
-		);
-	elseif (! isset ($seen_filenames[$data]))
+	if (! isset ($seen_data[$data]))
 	{
 		$styles[] = array
 		(
-			'type' => 'file',
+			'type' => $inline ? 'inline' : 'file',
 			'style' => $data,
 		);
-		$seen_filenames[$data] = 1;
+		$seen_data[$data] = 1;
 	}
 }
 
@@ -591,7 +531,7 @@ function getRenderedIPNetCapacity ($range)
 function getRenderedIPv4NetCapacity ($range)
 {
 	$class = 'net-usage';
-	if (isset ($range['addrc']))
+	if (isset ($range['own_addrlist']))
 	{
 		// full mode
 		// $a is "aquamarine zone", $b is "gray zone"
@@ -606,9 +546,9 @@ function getRenderedIPv4NetCapacity ($range)
 			foreach ($range['spare_ranges'] as $mask => $spare_list)
 				$a_total = bcadd ($a_total, bcmul (count ($spare_list), ip4_mask_size ($mask)), 0);
 		}
-		$a_used = $range['own_addrc'];
+		$a_used = markupIPAddrList ($range['own_addrlist']);
 		$b_total = bcsub ($total, $a_total, 0);
-		$b_used = $range['addrc'] - $a_used;
+		$b_used = markupIPAddrList ($range['addrlist']) - $a_used;
 
 		// generate link to progress bar image
 		$width = 100;
@@ -670,8 +610,8 @@ function getRenderedIPv6NetCapacity ($range)
 {
 	$div_id = $range['ip'] . '/' . $range['mask'];
 	$class = 'net-usage';
-	if (isset ($range['addrc']))
-		$used = $range['addrc'];
+	if (isset ($range['addrlist']))
+		$used = markupIPAddrList ($range['addrlist']);
 	else
 	{
 		$used = NULL;
@@ -723,6 +663,8 @@ function printPageHeaders ()
 	ksort ($pageheaders);
 	foreach ($pageheaders as $s)
 		echo $s . "\n";
+	// add tabindex to all input forms
+	addJS ('js/tabindex_auto.js', FALSE);
 
 	// add CSS styles
 	foreach (addCSS (NULL) as $item)
@@ -790,7 +732,7 @@ function serializeTags ($chain, $baseurl = '')
 			$parent_info[] = $taginfo['tag'];
 			if (strlen ($title))
 				$title .= "\n";
-			$title .= implode (" \xE2\x86\x92  ", $parent_info); # right arrow
+			$title .= implode (" &rarr;  ", $parent_info);
 		}
 		if (strlen ($title))
 			$title = "title='$title'";
@@ -909,7 +851,10 @@ function renderEntitySummary ($cell, $title, $values = array())
 function getOpLink ($params, $title,  $img_name = '', $comment = '', $class = '')
 {
 	if (isset ($params))
+	{
 		$ret = '<a href="' . makeHrefProcess ($params) . '"';
+		$class .= ' input';
+	}
 	else
 	{
 		$ret = '<a href="#" onclick="return false;"';
@@ -933,6 +878,30 @@ function getOpLink ($params, $title,  $img_name = '', $comment = '', $class = ''
 	return $ret;
 }
 
+function getPopupLink ($helper, $params, $window_name = '', $img_name = '', $title = '', $comment = '', $class = '')
+{
+	$ret = '';
+	$popup_args = 'height=700, width=700, location=no, menubar=no, resizable=yes, scrollbars=yes, status=no, titlebar=no, toolbar=no';
+	$ret .= '<a href="#"';
+	$class = trim ($class);
+	if (! empty ($class))
+		$ret .= ' class="' . htmlspecialchars ($class, ENT_QUOTES) . '"';
+	if (! empty ($comment))
+		$ret .= 'title="' . htmlspecialchars ($comment, ENT_QUOTES) . '"';
+	$href = makeHref (array ('module' => 'popup', 'helper' => $helper) + makePageParams ($params));
+	$ret .= " onclick=\"window.open('$href', '$window_name', '$popup_args'); return false\">";
+
+	if (! empty ($img_name))
+	{
+		$ret .= getImageHREF ($img_name, $comment);
+		if (! empty ($title))
+			$ret .= ' ';
+	}
+	$ret .= $title;
+	$ret .= '</a>';
+	return $ret;
+}
+
 function renderProgressBar ($percentage = 0, $theme = '', $inline = FALSE)
 {
 	echo getProgressBar ($percentage, $theme, $inline);
@@ -949,7 +918,6 @@ function getProgressBar ($percentage = 0, $theme = '', $inline = FALSE)
 		$_REQUEST['theme'] = $theme;
 		$src = 'data:image/png;base64,' . chunk_split (base64_encode (getOutputOf ('renderProgressBarImage', $done)));
 		$_REQUEST = $bk_request;
-		header ('Content-type: text/html');
 	}
 	$ret = "<img width=100 height=10 border=0 title='${done}%' src='$src'>";
 	return $ret;
@@ -961,7 +929,10 @@ function renderNetVLAN ($cell)
 		return;
 	$links = array();
 	foreach ($cell['8021q'] as $vi)
-		$links[] = mkA ($vi['vlan_id'], 'vlan', "${vi['domain_id']}-${vi['vlan_id']}");
+	{
+		$vlan_info = getVlanRow ("${vi['domain_id']}-${vi['vlan_id']}");
+		$links[] = formatVLANAsShortLink ($vlan_info);
+	}
 	$noun = count ($cell['8021q']) > 1 ? 'VLANs' : 'VLAN';
 	echo "<div class='vlan'><strong><small>${noun}</small> " . implode (', ', $links) . '</strong></div>';
 }
@@ -1037,6 +1008,12 @@ function niftyString ($string, $maxlen = 30, $usetags = TRUE)
 
 function printTagsPicker ($preselect=NULL)
 {
+	global $taglist;
+	if (! count ($taglist))
+	{
+		printf ('(None exist yet, %s?)', mkA ('configure', 'tagtree', NULL, 'edit'));
+		return;
+	}
 	printTagsPickerInput ();
 	printTagsPickerUl ($preselect);
 	enableTagsPicker ();
