@@ -543,8 +543,8 @@ $tab['portmap']['default'] = 'View';
 $tab['portmap']['edit'] = 'Edit';
 $tabhandler['portmap']['default'] = 'renderOIFCompatViewer';
 $tabhandler['portmap']['edit'] = 'renderOIFCompatEditor';
-$ophandler['portmap']['edit']['add'] = 'tableHandler';
-$ophandler['portmap']['edit']['del'] = 'tableHandler';
+$ophandler['portmap']['edit']['add'] = 'addOIFCompat';
+$ophandler['portmap']['edit']['del'] = 'delOIFCompat';
 $ophandler['portmap']['edit']['addPack'] = 'addOIFCompatPack';
 $ophandler['portmap']['edit']['delPack'] = 'delOIFCompatPack';
 
@@ -862,4 +862,8 @@ $ajaxhandler['net-usage'] = 'getNetUsageAJAX';
 $ajaxhandler['get-slb-form'] = 'renderSLBFormAJAX';
 $ajaxhandler['triplet-preview'] = 'getTripletConfigAJAX';
 
+$popuphandler['objlist'] = 'renderPopupObjectSelector';
+$popuphandler['portlist'] = 'renderPopupPortSelector';
+$popuphandler['inet4list'] = 'renderPopupIPv4Selector';
+
 ?>
