@@ -106,6 +106,8 @@ function generateVSSection ($vs_parser)
 			continue;
 		$parser = clone $vs_parser;
 		$parser->addMacro ('RSIP', $rs['rsip']);
+		if (isset ($rs['rsport']))
+			$parser->addMacro ('RSPORT', $rs['rsport']);
 		$parser->addMacro ('RS_COMMENT', $rs['comment']);
 		$parser->addMacro ('RS_RS_CONF', $rs['rsconfig']);
 
@@ -370,7 +372,7 @@ function isVIPEnabled ($vip, $vip_list)
 	return FALSE;
 }
 
-// returns list of ipv4vs ids which have one of the IPs or fwmarks of group $group_id
+// returns list of ipv4vs ids that have one of the IPs or fwmarks of group $group_id
 function getVSIDsByGroup ($group_id)
 {
 	$ret = array();
@@ -636,7 +638,7 @@ function commitDeleteVSG ($id)
 	usePreparedDeleteBlade ('VS', array ('id' => $id));
 }
 
-// returns an array of object_ids which have links to a given VS
+// returns an array of object_ids that have links to a given VS
 // may be used as 'refcnt'
 function getVSLinkedObjects ($vs_id)
 {
